@@ -30,9 +30,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-"""
-Generate localized country labels.
-"""
+"""Generate localized country labels."""
 
 from __future__ import print_function
 
@@ -41,18 +39,19 @@ from argparse import ArgumentParser, FileType
 
 import _util
 
+
 if __name__ == '__main__':
-	parser = ArgumentParser(description=__doc__)
-	parser.add_argument("languageCode", nargs="+")
-	parser.add_argument("outfile", type=FileType("w"))
-	opt = parser.parse_args()
+    parser = ArgumentParser(description=__doc__)
+    parser.add_argument("languageCode", nargs="+")
+    parser.add_argument("outfile", type=FileType("w"))
+    opt = parser.parse_args()
 
-	print('generating country label data...')
-	countries = _util.get_country_code_to_geonameid_map(3)
-	country_ids = set(countries.values())
-	labels = _util.get_localized_names(country_ids, opt.languageCode)
-	final_lables = {icountry: labels.get(igeonameid, '') for icountry, igeonameid in countries.items()}
-	json.dump(final_lables, opt.outfile, ensure_ascii=False, indent=2, sort_keys=True)
-	opt.outfile.write("\n")
+    print('generating country label data...')
+    countries = _util.get_country_code_to_geonameid_map(3)
+    country_ids = set(countries.values())
+    labels = _util.get_localized_names(country_ids, opt.languageCode)
+    final_lables = {icountry: labels.get(igeonameid, '') for icountry, igeonameid in countries.items()}
+    json.dump(final_lables, opt.outfile, ensure_ascii=False, indent=2, sort_keys=True)
+    opt.outfile.write("\n")
 
-	print('... done :)')
+    print('... done :)')
